﻿-------------------------------------------------------------------------------
-- Project: GridGroupNumber
-- Version: 1.0
-- File: GridGroupNumber.lua
-- Last Modified: 2013/04/28
-- Author: Alex Tam (Hong Kong)
-- Project desc: Display Group Number on Grid
-------------------------------------------------------------------------------

local _, L = ...

local GridRoster = Grid:GetModule("GridRoster")
local GridGroupNumber = Grid:GetModule("GridStatus"):NewModule("GridGroupNumber")
GridGroupNumber.menuName = L["MOD_NAME"]

local images_folder = "Interface\\AddOns\\GridGroupNumber\\images\\"

GridGroupNumber.defaultDB = {
	group_number = {
		text = L["MOD_NAME"],
		enable = true,
		color = { r = 0.25, g = 1.0, b = 0.25, a = 1 },
		priority = 5,
		range = false,
		icon = false,
	},
}

-- initialize
function GridGroupNumber:OnInitialize()
  
	self.super.OnInitialize(self)
	self:Debug("OnInitialize")
	self:RegisterStatus("group_number", L["MOD_NAME"])
  
end

-- Enable
function GridGroupNumber:OnEnable()
  
	self:Debug("OnEnable")
	self:RegisterEvent("GROUP_ROSTER_UPDATE")
	self:RegisterEvent("PLAYER_LOGIN")
  
	self:Update()
  
end

function GridGroupNumber:OnDisable()
  
	self:Debug("OnDisable")
  self:UnregisterEvent("GROUP_ROSTER_UPDATE")
	self:UnregisterEvent("PLAYER_LOGIN")
  
end


-- Reset
function GridGroupNumber:Reset()
  
	self.super.Reset(self)
	self:OnDisable()
	self:OnEnable()
  
end

function GridGroupNumber:PLAYER_LOGIN()
  
  self:Debug("PLAYER_LOGIN")
  
  local guid = UnitGUID("player")
  self:Debug("Player GUID=%s", guid)
  
  if not IsInRaid() then
    
    -- Set Group number as zero on login and not in raid
    local group_number = self.db.profile.group_number  
    local icon = format("%sG%s.tga", images_folder, 0)
    
    self.core:SendStatusGained(
          guid, 
          "group_number",
          group_number.priority,
          (group_number.range and 40),
          group_number.color,
          format("%u", 0),
          nil,
          nil,
          icon)
  else
    self:Update()
  end
  
  
end


function GridGroupNumber:GROUP_ROSTER_UPDATE()
  
  self:Debug("GROUP_ROSTER_UPDATE")
  self:Update()
  
end

function GridGroupNumber:Update()
  
  if IsInRaid() then
		self:Debug("Update", "raid")
		return self:UpdateRaid()
  else
    self:Debug("Not IsInRaid")
  end
	
end

function GridGroupNumber:UpdateRaid()
  
	self:Debug("UpdateRaid, raid members=%s", GetNumGroupMembers())
  local group_number = self.db.profile.group_number  
    

	for i = 1, GetNumGroupMembers() do
		local unit = "raid"..i
		local guid = UnitGUID("raid"..i)
		local name, _, subgroup, _, _, _, _, _, _, _, _ = GetRaidRosterInfo(i)
    local icon = nil
    
    -- self:Debug("UpdateRaid name=%s, subgroup=%s", name, subgroup)
    
    if subgroup > 0 and subgroup < 9 then
      icon = format("%sG%s.tga", images_folder, subgroup)
    else
      icon = nil
    end
   
		self.core:SendStatusGained(
        guid, 
        "group_number",
				group_number.priority,
				(group_number.range and 40),
				group_number.color,
				format("%u", subgroup),
				nil,
				nil,
				icon)
	end
  
end

